@@ -21,7 +21,14 @@
 # the dot is necessary to avoid name conflict. 
 # from .vector import vector
 
-# from .vector import vector
+# exception handling is best solution to any problem
+# here in
+try:
+    from .vector import vector  # this import is for the build version
+except :
+    pass        # simply ignore the error and the module will be imported 
+# pass will simply ignore the import command here and test files will import the module by
+# the local command written in them
 
 
 """
